@@ -57,6 +57,11 @@ static void filter( const char* u, const char * expectedResult = 0, int expected
 
     if (KUriFilter::self()->filterUri(*filterData, list))
     {
+        if ( expectedUriType == NO_FILTERING ) {
+            kError() << u << "Did not expect filtering. Got" << filterData->uri();
+            QVERIFY( expectedUriType != NO_FILTERING ); // fail the test
+        }
+
         // Copied from minicli...
         QString cmd;
         KUrl uri = filterData->uri();
@@ -97,10 +102,10 @@ static void filter( const char* u, const char * expectedResult = 0, int expected
 
         if ( expectedUriType != -1 && expectedUriType != filterData->uriType() )
         {
+            kError() << u << "Got URI type" << s_uritypes[filterData->uriType()]
+                      << "expected" << s_uritypes[expectedUriType];
             QCOMPARE( s_uritypes[filterData->uriType()],
                       s_uritypes[expectedUriType] );
-            kError() << " Got URI type " << s_uritypes[filterData->uriType()]
-                      << " expected " << s_uritypes[expectedUriType] << endl;
         }
 
         if ( expectedResult )
@@ -108,7 +113,10 @@ static void filter( const char* u, const char * expectedResult = 0, int expected
             // Hack for other locales than english, normalize google hosts to google.com
             cmd = cmd.replace( QRegExp( "www\\.google\\.[^/]*/" ), "www.google.com/" );
             QString expected = QString::fromUtf8( expectedResult );
-            QCOMPARE( cmd, expected );
+            if (cmd != expected) {
+                kError() << u;
+                QCOMPARE( cmd, expected );
+            }
         }
     }
     else
@@ -198,7 +206,8 @@ void KUriFilterTest::localFiles()
 {
     filter( "/", "/", KUriFilterData::LocalDir );
     filter( "/", "/", KUriFilterData::LocalDir, QStringList( "kshorturifilter" ) );
-    filter( "~/.bashrc", QDir::homePath().toLocal8Bit()+"/.bashrc", KUriFilterData::LocalFile, QStringList( "kshorturifilter" ) );
+    if (QFile::exists(QDir::homePath() + QLatin1String("/.bashrc")))
+        filter( "~/.bashrc", QDir::homePath().toLocal8Bit()+"/.bashrc", KUriFilterData::LocalFile, QStringList( "kshorturifilter" ) );
     filter( "~", QDir::homePath().toLocal8Bit(), KUriFilterData::LocalDir, QStringList( "kshorturifilter" ), "/tmp" );
     filter( "~foobar", 0, KUriFilterData::Error, QStringList( "kshorturifilter" ) );
 
