@@ -40,13 +40,14 @@
 #include <knewpassworddialog.h>
 #include <kstandarddirs.h>
 #include <kwalletentry.h>
+#include <kicon.h>
 #include <kwindowsystem.h>
 #include <kpluginfactory.h>
 #include <kpluginloader.h>
 #include <KNotification>
 
 #include <QtCore/QDir>
-#include <QtGui/QTextDocument> // Qt::escape
+#include <QTextDocument> // Qt::escape
 #include <QtCore/QRegExp>
 #include <QtCore/QTimer>
 #include <QtCore/QEventLoop>
