@@ -179,15 +179,13 @@ void Nepomuk2::SearchProtocol::listDir( const KUrl& url )
             listEntry( KIO::UDSEntry(),  true);
             finished();
         }
-        else if ( SearchFolder* folder = getQueryFolder( url ) ) {
+        else {
+            SearchFolder folder( url, this );
             updateQueryUrlHistory( url );
-            folder->list();
+            folder.waitForListing();
             listEntry( KIO::UDSEntry(), true );
             finished();
         }
-        else {
-            error( KIO::ERR_DOES_NOT_EXIST, url.prettyUrl() );
-        }
     }
 
     // listing of query results that are folders
@@ -315,7 +313,9 @@ void Nepomuk2::SearchProtocol::listRoot()
 
     Query::Query query = rootQuery();
     if ( query.isValid() ) {
-        getQueryFolder( query.toSearchUrl() )->list();
+        // FIXME: Avoid this useless conversion to searchUrl and back
+        SearchFolder folder( query.toSearchUrl(), this );
+        folder.waitForListing();
     }
 
     listEntry( KIO::UDSEntry(), true );
@@ -323,12 +323,6 @@ void Nepomuk2::SearchProtocol::listRoot()
 }
 
 
-Nepomuk2::SearchFolder* Nepomuk2::SearchProtocol::getQueryFolder( const KUrl& url )
-{
-    return new SearchFolder( url, this );
-}
-
-
 void Nepomuk2::SearchProtocol::updateQueryUrlHistory( const KUrl& url )
 {
     //
